---
title: 네이버페이(주문형) 상점아이디 추가 절차
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 서비스 추가/변경
seo:
  title: 네이버페이(주문형) 상점아이디추가
  description: >-
    네이버페이(주문형)의 상점아이디(사이트코드) 추가절차를 안내드립니다. 추가 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되며,
    네이버페이의 상점아이디 절차는 신규 가입절차와 동일합니다.
  keywords:
    - 네이버페이(주문형)
    - 서비스추가/변경
tags:
  - 네이버페이(주문형)
  - 서비스추가/변경
pgCompanies:
  - 네이버페이(주문형)
searchTags:
  - 상점아이디 추가
  - 파트너ID
  - 네이버페이
  - 상점아이디추가
  - MID추가
  - 네이버페이 상점아이디추가
  - 네이버페이 상점아이디 추가
  - 파트너ID추가
  - 파트너ID 추가
  - 주문형 상점아이디추가
  - 주문형 상점아이디 추가
  - '네이버페이 주문형 상점아이디 추가 '
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="네이버페이(주문형) 상점아이디 추가 절차를 안내해드립니다. 추가되는 상점아이디는 포트원 호스팅사를 기준으로 수수료가 적용되는 점 참고해주세요." />

<Callout title="포트원 기준 결제대행사 수수료 보러가기↗" />

### **상점아이디 추가 케이스**

<Callout content="1. 네이버페이의 상점아이디 추가 절차는 신규 계약절차와 동일하게 진행됩니다. 
기존에 다른 사이트 URL로 가입하신 적이 있으신 경우 **포트원 고객지원팀으로 관리자콘솔 내 새로운 URL로 적용되도록 요청해주시기 바랍니다.**
2. 네이버페이 정책상 상점아이디 추가시 검수과정 재진행이 필요합니다.
3. 포트원 정책에 의하여 기존에 포트원을 통하지 않고 계약된 상점아이디는 포트원 서비스 사용이 불가합니다. 새로운 포트원용 상점아이디를 추가 발급 받으신 후 이용해주시기 바랍니다." title="참고사항" icon="💡" />

- 이미 네이버페이와 직접 계약이 되어있다가 포트원으로 연동하시는 경우
- 다른 호스팅사를 통해 네이버페이와 계약 되어있다가 포트원으로 연동하시는 경우
- 새로운 서비스가 추가되는 경우 (판매품목, 업종이 변경되거나 추가되는 경우)
- 심사 받은 적 없는 연동 방식을 추가하시는 경우 (ex. 일반결제 사용중에 정기결제 추가시)

### **신청방법**

<Indent level="1">

1\. 네이버페이 신규 가입신청

2\. 네이버페이 1차 심사 및 승인 안내

3\. 승인시 테스트용으로 설정된 상점정보 발급 (네이버측에서 메일로 안내)

4\. 개발 · 연동

5\. 네이버페이(<dl_techsupport@navercorp.com>) 로 검수요청 (테스트환경 설정 요청)

6\. 검수완료

7\. 고객사에서 실 운영환경으로 전환 후 **네이버페이측에 운영환경 설정요청**

</Indent>

<Callout title="네이버페이(주문형) 상세 계약절차 보러가기↗" />
